==> v21.10.zip: bookstack/resources/lang/zh_CN/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => '取消',
    'confirm' => '确认',
    'back' => '返回',
    'save' => '保存',
    'continue' => '继续',
    'select' => '选择',
    'toggle_all' => '切换全部',
    'more' => '更多',

    // Form Labels
    'name' => '名称',
    'description' => '概要',
    'role' => '角色',
    'cover_image' => '封面图片',
    'cover_image_description' => '该图像大小需要为440x250px。',
    
    // Actions
    'actions' => '操作',
    'view' => '浏览',
    'view_all' => '查看全部',
    'create' => '创建',
    'update' => '更新',
    'edit' => '编辑',
    'sort' => '排序',
    'move' => '移动',
    'copy' => '复制',
    'reply' => '回复',
    'delete' => '删除',
    'delete_confirm' => '确认删除',
    'search' => '搜索',
    'search_clear' => '清除搜索',
    'reset' => '重置',
    'remove' => '删除',
    'add' => '添加',
    'configure' => '配置',
    'fullscreen' => '全屏',
    'favourite' => '收藏',
    'unfavourite' => '取消收藏',
    'next' => '下一页',
    'previous' => '上一页',

    // Sort Options
    'sort_options' => '排序选项',
    'sort_direction_toggle' => '排序方向切换',
    'sort_ascending' => '升序',
    'sort_descending' => '降序',
    'sort_name' => '名称',
    'sort_default' => '默认',
    'sort_created_at' => '创建时间',
    'sort_updated_at' => '更新时间',

    // Misc
    'deleted_user' => '删除用户',
    'no_activity' => '没有活动要显示',
    'no_items' => '没有可用的项目',
    'back_to_top' => '回到顶部',
    'skip_to_main_content' => '跳转到主要内容',
    'toggle_details' => '显示/隐藏详细信息',
    'toggle_thumbnails' => '显示/隐藏缩略图',
    'details' => '详细信息',
    'grid_view' => '网格视图',
    'list_view' => '列表视图',
    'default' => '默认',
    'breadcrumb' => '面包屑导航',

    // Header
    'header_menu_expand' => '展开标头菜单',
    'profile_menu' => '个人资料',
    'view_profile' => '查看资料',
    'edit_profile' => '编辑资料',
    'dark_mode' => '夜间模式',
    'light_mode' => '日间模式',

    // Layout tabs
    'tab_info' => '信息',
    'tab_info_label' => '标签：显示次要信息',
    'tab_content' => '内容',
    'tab_content_label' => '标签：显示主要内容',

    // Email Content
    'email_action_help' => '如果您无法点击“:actionText”按钮，请将下面的网址复制到您的浏览器中打开：',
    'email_rights' => '版权所有',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => '隐私政策',
    'terms_of_service' => '服务条款',
];

==> v22.11.zip: bookstack/resources/lang/zh_CN/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => '取消',
    'confirm' => '确认',
    'back' => '返回',
    'save' => '保存',
    'continue' => '继续',
    'select' => '选择',
    'toggle_all' => '切换全部',
    'more' => '更多',

    // Form Labels
    'name' => '名称',
    'description' => '概要',
    'role' => '角色',
    'cover_image' => '封面图片',
    'cover_image_description' => '此图像大小应约为 440x250 像素。',

    // Actions
    'actions' => '操作',
    'view' => '浏览',
    'view_all' => '查看全部',
    'new' => 'New',
    'create' => '创建',
    'update' => '更新',
    'edit' => '编辑',
    'sort' => '排序',
    'move' => '移动',
    'copy' => '复制',
    'reply' => '回复',
    'delete' => '删除',
    'delete_confirm' => '确认删除',
    'search' => '搜索',
    'search_clear' => '清除搜索',
    'reset' => '重置',
    'remove' => '删除',
    'add' => '添加',
    'configure' => '配置',
    'fullscreen' => '全屏',
    'favourite' => '收藏',
    'unfavourite' => '取消收藏',
    'next' => '下一页',
    'previous' => '上一页',
    'filter_active' => '标签过滤器：',
    'filter_clear' => '清除过滤器',
    'download' => '下载',
    'open_in_tab' => '在标签页中打开。',

    // Sort Options
    'sort_options' => '排序选项',
    'sort_direction_toggle' => '排序方向切换',
    'sort_ascending' => '升序',
    'sort_descending' => '降序',
    'sort_name' => '名称',
    'sort_default' => '默认',
    'sort_created_at' => '创建时间',
    'sort_updated_at' => '更新时间',

    // Misc
    'deleted_user' => '删除用户',
    'no_activity' => '没有活动要显示',
    'no_items' => '没有可用的项目',
    'back_to_top' => '回到顶部',
    'skip_to_main_content' => '跳转到主要内容',
    'toggle_details' => '显示/隐藏详细信息',
    'toggle_thumbnails' => '显示/隐藏缩略图',
    'details' => '详细信息',
    'grid_view' => '网格视图',
    'list_view' => '列表视图',
    'default' => '默认',
    'breadcrumb' => '面包屑导航',
    'status' => '状态',
    'status_active' => '已激活',
    'status_inactive' => '未激活',
    'never' => '从未',
    'none' => '无',

    // Header
    'homepage' => 'Homepage',
    'header_menu_expand' => '展开标头菜单',
    'profile_menu' => '个人资料',
    'view_profile' => '查看个人资料',
    'edit_profile' => '编辑个人资料',
    'dark_mode' => '夜间模式',
    'light_mode' => '日间模式',
    'global_search' => 'Global Search',

    // Layout tabs
    'tab_info' => '信息',
    'tab_info_label' => '标签：显示次要信息',
    'tab_content' => '内容',
    'tab_content_label' => '标签：显示主要内容',

    // Email Content
    'email_action_help' => '如果您无法点击“:actionText”按钮，请将下面的网址复制到您的浏览器中打开：',
    'email_rights' => '版权所有',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => '隐私政策',
    'terms_of_service' => '服务条款',
];
